@@ -25,12 +25,10 @@ class KafkaHelper:
         self.sasl_config = {}
         if kwargs.get("username"):
             username = kwargs.pop("username")
-            self.sasl_config.update({"sasl_plain_username": username})
         else:
             username = options.rabbitmq_config.get("username")
         if kwargs.get("password"):
             password = kwargs.pop("password")
-            self.sasl_config.update({"sasl_plain_password": username})
         else:
             password = options.rabbitmq_config.get("password")
         if username and password:
