@@ -113,6 +113,8 @@ class StatusCode:
     TASK_SUCCESS = ("B0103", "任务成功")
     TASK_FAIL = ("B0104", "任务失败")
     TASK_NOT_EXIST = ("B0105", "任务不存在")
+    COMPANY_CERTIFICATION_FAIL = ("B0106", "企业认证失败")
+    IDENTITY_CERTIFICATION_FAIL = ("B0107", "身份证认证失败")
     # B02开头的状态码
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     # B03开头的状态码
